==> ackee-frontend-toolkit-0.7.0.tgz: package/es/modules/chat/components/Messages/Messages.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { React, PropTypes, pure, _get, _last } from '../../dependencies';

import Message, { authorShape } from './Message';
import LoadMoreButton from '../LoadMoreButton';
import UnseenSeparator from './UnseenSeparator';

var rootElementId = 'conversation__messages';

var Messages = function (_React$Component) {
    _inherits(Messages, _React$Component);

    function Messages() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, Messages);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = Messages.__proto__ || Object.getPrototypeOf(Messages)).call.apply(_ref, [this].concat(args))), _this), _this.handleLoadMore = function () {
            var incChatPage = _this.props.incChatPage;
            var _this$props = _this.props,
                messagesCount = _this$props.messagesCount,
                messages = _this$props.messages;

            if (messages.length < messagesCount) {
                incChatPage();
            }
        }, _this.renderMessage = function (message) {
            var _this$props2 = _this.props,
                conversationId = _this$props2.conversationId,
                MessageAuthor = _this$props2.MessageAuthor,
                MessageImage = _this$props2.MessageImage;


            return React.createElement(Message, _extends({}, message, {
                key: message.messageId,
                conversationId: conversationId,
                MessageAuthor: MessageAuthor,
                MessageImage: MessageImage
            }));
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(Messages, [{
        key: 'componentDidUpdate',
        value: function componentDidUpdate(prevProps) {
            var _props = this.props,
                conversationId = _props.conversationId,
                isLoaded = _props.isLoaded,
                messages = _props.messages,
                conversationMessagesLoaded = _props.conversationMessagesLoaded;


            var last = _last(prevProps.messages) || {};
            var lastNew = _last(messages) || {};

            if (prevProps.unseenMessagesCount !== this.props.unseenMessagesCount || prevProps.sentMessagesCount !== this.props.sentMessagesCount || last.messageId !== lastNew.messageId) {
                Messages.scrollToBottom();
            }

            if (!prevProps.isLoaded && isLoaded) {
                var unseenMessagesCount = Math.max(0, this.props.unseenMessagesCount);
                var firstUnseenMessage = messages[messages.length - unseenMessagesCount];

                conversationMessagesLoaded(conversationId, _get(firstUnseenMessage, 'messageId', null));
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                messagesCount = _props2.messagesCount,
                isLoaded = _props2.isLoaded,
                isEmpty = _props2.isEmpty,
                messages = _props2.messages,
                readMessagesCount = _props2.readMessagesCount,
                loadingPlaceholder = _props2.loadingPlaceholder;

            var unseenMessagesCount = Math.max(0, this.props.unseenMessagesCount);

            var readMessages = messages.slice(0, readMessagesCount);
            var unreadMessages = messages.slice(readMessagesCount);

            return React.createElement(
                'div',
                { id: rootElementId, className: 'conversation__messages' },
                isLoaded && !isEmpty && React.createElement(
                    React.Fragment,
                    null,
                    React.createElement(
                        'div',
                        { className: 'conversation__messages-loader' },
                        React.createElement(LoadMoreButton, { disabled: messages.length >= messagesCount, onClick: this.handleLoadMore })
                    ),
                    readMessages.map(this.renderMessage)
                ),
                readMessagesCount < messages.length && React.createElement(UnseenSeparator, { unseen: unseenMessagesCount }),
                isLoaded && !isEmpty && unreadMessages.map(this.renderMessage),
                !isLoaded && loadingPlaceholder
            );
        }
    }], [{
        key: 'scrollToBottom',
        value: function scrollToBottom() {
            var div = document.getElementById(rootElementId);
            div.scrollTop = div.scrollHeight - div.clientHeight;
        }
    }]);

    return Messages;
}(React.Component);

Messages.propTypes = {
    // userId and conversationId are used by container, but since they're important
    // props, we're typechecking them here
    userId: PropTypes.string.isRequired,
    conversationId: PropTypes.string.isRequired,

    messagesCount: PropTypes.number,
    unseenMessagesCount: PropTypes.number,
    isLoaded: PropTypes.bool.isRequired,
    isEmpty: PropTypes.bool.isRequired,
    messages: PropTypes.arrayOf(PropTypes.shape({
        messageId: PropTypes.string.isRequired,
        author: authorShape,
        text: PropTypes.string,
        time: PropTypes.number
    })),
    sentMessagesCount: PropTypes.number.isRequired,
    loadingPlaceholder: PropTypes.node,
    incChatPage: PropTypes.func.isRequired,
    conversationMessagesLoaded: PropTypes.func.isRequired,
    readMessagesCount: PropTypes.number.isRequired,
    MessageAuthor: PropTypes.func,
    MessageImage: PropTypes.func
};
Messages.defaultProps = {
    messagesCount: 0,
    unseenMessagesCount: 0,
    messages: [],
    loadingPlaceholder: React.createElement(
        'span',
        { className: 'conversation__loading' },
        'Loading'
    ),
    MessageAuthor: undefined,
    MessageImage: undefined
};


export default pure(Messages);

==> ackee-frontend-toolkit-0.8.1.tgz: package/es/modules/chat/components/Messages/Messages.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { React, PropTypes, pure, _get, _last } from '../../dependencies';

import Message, { authorShape } from './Message';
import LoadMoreButton from '../LoadMoreButton';
import UnseenSeparator from './UnseenSeparator';

var rootElementId = 'conversation__messages';

var Messages = function (_React$Component) {
    _inherits(Messages, _React$Component);

    function Messages() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, Messages);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = Messages.__proto__ || Object.getPrototypeOf(Messages)).call.apply(_ref, [this].concat(args))), _this), _this.handleLoadMore = function () {
            var incChatPage = _this.props.incChatPage;
            var _this$props = _this.props,
                messagesCount = _this$props.messagesCount,
                messages = _this$props.messages;

            if (messages.length < messagesCount) {
                incChatPage();
            }
        }, _this.renderMessage = function (message) {
            var _this$props2 = _this.props,
                conversationId = _this$props2.conversationId,
                MessageAuthor = _this$props2.MessageAuthor,
                MessageImage = _this$props2.MessageImage,
                MessageComponent = _this$props2.MessageComponent;


            return React.createElement(MessageComponent, _extends({}, message, {
                key: message.messageId,
                conversationId: conversationId,
                MessageAuthor: MessageAuthor,
                MessageImage: MessageImage
            }));
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(Messages, [{
        key: 'componentDidUpdate',
        value: function componentDidUpdate(prevProps) {
            var _props = this.props,
                conversationId = _props.conversationId,
                isLoaded = _props.isLoaded,
                messages = _props.messages,
                conversationMessagesLoaded = _props.conversationMessagesLoaded;


            var last = _last(prevProps.messages) || {};
            var lastNew = _last(messages) || {};

            if (prevProps.unseenMessagesCount !== this.props.unseenMessagesCount || prevProps.sentMessagesCount !== this.props.sentMessagesCount || last.messageId !== lastNew.messageId) {
                Messages.scrollToBottom();
            }

            if (!prevProps.isLoaded && isLoaded) {
                var unseenMessagesCount = Math.max(0, this.props.unseenMessagesCount);
                var firstUnseenMessage = messages[messages.length - unseenMessagesCount];

                conversationMessagesLoaded(conversationId, _get(firstUnseenMessage, 'messageId', null));
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                messagesCount = _props2.messagesCount,
                isLoaded = _props2.isLoaded,
                isEmpty = _props2.isEmpty,
                messages = _props2.messages,
                readMessagesCount = _props2.readMessagesCount,
                loadingPlaceholder = _props2.loadingPlaceholder;

            var unseenMessagesCount = Math.max(0, this.props.unseenMessagesCount);

            var readMessages = messages.slice(0, readMessagesCount);
            var unreadMessages = messages.slice(readMessagesCount);

            return React.createElement(
                'div',
                { id: rootElementId, className: 'conversation__messages' },
                isLoaded && !isEmpty && React.createElement(
                    React.Fragment,
                    null,
                    React.createElement(
                        'div',
                        { className: 'conversation__messages-loader' },
                        React.createElement(LoadMoreButton, { disabled: messages.length >= messagesCount, onClick: this.handleLoadMore })
                    ),
                    readMessages.map(this.renderMessage)
                ),
                readMessagesCount < messages.length && React.createElement(UnseenSeparator, { unseen: unseenMessagesCount }),
                isLoaded && !isEmpty && unreadMessages.map(this.renderMessage),
                !isLoaded && loadingPlaceholder
            );
        }
    }], [{
        key: 'scrollToBottom',
        value: function scrollToBottom() {
            var div = document.getElementById(rootElementId);
            div.scrollTop = div.scrollHeight - div.clientHeight;
        }
    }]);

    return Messages;
}(React.Component);

Messages.propTypes = {
    // userId and conversationId are used by container, but since they're important
    // props, we're typechecking them here
    userId: PropTypes.string.isRequired,
    conversationId: PropTypes.string.isRequired,

    messagesCount: PropTypes.number,
    unseenMessagesCount: PropTypes.number,
    isLoaded: PropTypes.bool.isRequired,
    isEmpty: PropTypes.bool.isRequired,
    messages: PropTypes.arrayOf(PropTypes.shape({
        messageId: PropTypes.string.isRequired,
        author: authorShape,
        text: PropTypes.string,
        time: PropTypes.number
    })),
    sentMessagesCount: PropTypes.number.isRequired,
    loadingPlaceholder: PropTypes.node,
    incChatPage: PropTypes.func.isRequired,
    conversationMessagesLoaded: PropTypes.func.isRequired,
    readMessagesCount: PropTypes.number.isRequired,
    MessageAuthor: PropTypes.func,
    MessageImage: PropTypes.func,
    MessageComponent: PropTypes.func
};
Messages.defaultProps = {
    messagesCount: 0,
    unseenMessagesCount: 0,
    messages: [],
    loadingPlaceholder: React.createElement(
        'span',
        { className: 'conversation__loading' },
        'Loading'
    ),
    MessageAuthor: undefined,
    MessageImage: undefined,
    MessageComponent: Message
};


export default pure(Messages);
